@@ -97,6 +97,13 @@ NOMODULES=$nomodules
 ###################
 # Main program
 
+(
+
+echo
+echo I am logging everything into \"install.log\".
+sleep 3
+
+
 echo
 echo You appear to be running on a system that does not use the
 echo RPM packaging system.
@@ -276,10 +283,10 @@ IsABundle	MailTools	2.02	1	yes	noarch
 IO		IO		1.2301	1	yes	noarch
 Test::Harness	Test-Harness	2.64	1	yes	noarch
 Test::Simple	Test-Simple	0.70	1	no	noarch
-File::Temp	File-Temp	0.19	1	yes	noarch
+File::Temp	File-Temp	0.20	1	yes	noarch
 HTML::Tagset	HTML-Tagset	3.03	1	yes	noarch
 HTML::Parser	HTML-Parser	3.56	1	yes	i386
-IsABundle	MIME-tools	5.425	1	yes	noarch
+IsABundle	MIME-tools	5.427	1	yes	noarch
 Convert::TNEF	Convert-TNEF	0.17	1	yes	noarch
 Compress::Zlib	Compress-Zlib	1.41	1	yes	i386
 Archive::Zip	Archive-Zip	1.16	1	yes	noarch
@@ -397,3 +404,6 @@ echo 'If you want help setting up MailScanner, please read the Wiki'
 echo 'at wiki.mailscanner.info and buy the MailScanner book at'
 echo 'www.mailscanner.info'
 echo
+
+) 2>&1 | tee install.log
+
