@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm 4417 2008-04-23 14:28:08Z sysjkf $
+#   $Id: MessageBatch.pm 4544 2008-09-16 11:28:33Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use POSIX;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4417 $, 10;
+$VERSION = substr q$Revision: 4544 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -508,17 +508,17 @@ sub Explode {
 sub VirusScan {
   my $this = shift;
 
+  #MailScanner::Log::InfoLog("Other Checks: Starting");
+  my $others  = MailScanner::SweepOther::ScanBatch($this, 'scan');
+  MailScanner::Log::NoticeLog("Other Checks: Found %d problems", $others+0)
+    if defined $others && $others>0;
+
   # Call them with the scanning settings
   MailScanner::Log::InfoLog("Virus and Content Scanning: Starting");
   my $viruses = MailScanner::SweepViruses::ScanBatch($this, 'scan');
   MailScanner::Log::NoticeLog("Virus Scanning: Found %d viruses", $viruses+0)
     if defined $viruses && $viruses>0;
 
-  #MailScanner::Log::InfoLog("Other Checks: Starting");
-  my $others  = MailScanner::SweepOther::ScanBatch($this, 'scan');
-  MailScanner::Log::NoticeLog("Other Checks: Found %d problems", $others+0)
-    if defined $others && $others>0;
-
   #MailScanner::Log::InfoLog("Content Checks: Starting");
   my $content  = MailScanner::SweepContent::ScanBatch($this, 'scan');
   MailScanner::Log::NoticeLog("Content Checks: Found %d problems", $content+0)
@@ -739,9 +739,11 @@ sub SignUninfected {
 
   while(($id, $message) = each %{$this->{messages}}) {
     next if $message->{deleted} || $message->{dontdeliver};
-    $message->SignUninfected()
-      if MailScanner::Config::Value('signcleanmessages', $message) &&
-         !$message->{infected};
+    if (MailScanner::Config::Value('signcleanmessages', $message) &&
+         !$message->{infected}) {
+      $message->IsAReply();
+      $message->SignUninfected();
+    }
   }
 }
 
@@ -1164,7 +1166,7 @@ sub CreateEicarBatch {
   # Message number = 1
   # Path = irrelevant as we're not actually reading anything
   # It's a fake that we simulate ==> 1
-  my $newmessage = MailScanner::Message->new(1, '/tmp', 1);
+  my $newmessage = MailScanner::Message->new(1, '/tmp', 0, 1);
   @{$newmessage->{headers}} = ();
   @{$newmessage->{to}} = ();
   @{$newmessage->{touser}} = ();
