@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Sendmail.pm 4372 2008-04-02 15:45:26Z sysjkf $
+#   $Id: Sendmail.pm 4522 2008-08-20 15:19:23Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use Encode;
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4372 $, 10;
+$VERSION = substr q$Revision: 4522 $, 10;
 
 # Command-line options you need to give to sendmail to sensibly process a
 # message that is piped to it. Still need to add "-f" for specifying the
@@ -271,7 +271,7 @@ my($sed) = "/bin/sed";
 
   # Change for V4: returns lower-case $from and @to
   sub ReadQf {
-    my($this, $message) = @_;
+    my($this, $message, $getipfromheader) = @_;
 
     my($RQf) = $message->{store}{inhhandle};
 
@@ -279,6 +279,7 @@ my($sed) = "/bin/sed";
     my($ip, $Rline);
     my($Line, $Flags);
     my($RFound, $SFound, $IPFound);
+    my($ipfromheader, $read1strcvd);
 
     #$message->{store}->print();
 
@@ -356,10 +357,24 @@ my($sed) = "/bin/sed";
         $message->{subject} = $1;
         $InSubject = 1;
       }
+      if ($Line =~ /^Received: .+\[(\d+\.\d+\.\d+\.\d+)\]/i) {
+        unless ($read1strcvd) {
+          $ipfromheader = $1;
+          $read1strcvd = 1;
+        }
+      } elsif ($Line =~ /^Received: .+\[([\dabcdef.:]+)\]/i) {
+        unless ($read1strcvd) {
+          $ipfromheader = $1;
+          $read1strcvd = 1;
+        }
+      }
     }
     # Not every qf file defined an IP address if it is a bounce.
     # So provide an IP if we haven't found one.
     $message->{clientip} = '0.0.0.0' unless $IPFound;
+    # If we were told to read the IP from the header, and it was there
+    $message->{clientip} = $ipfromheader
+      if $read1strcvd && $getipfromheader && $ipfromheader ne "";
 
     # Decode ISO subject lines into UTF8
     # Needed for UTF8 support in MailWatch 2.0
@@ -482,6 +497,7 @@ my($sed) = "/bin/sed";
     $this->AddHeader($message, $key, $newvalue);
   }
 
+
   sub AppendHeader {
     my($this, $message, $key, $newvalue, $sep) = @_;
 
@@ -841,6 +857,7 @@ my($sed) = "/bin/sed";
     my(%ModDate, $mta, $file, $tmpdate, $invalidfiles);
     my(@SortedFiles, $id, $newmessage, @queuedirnames);
     my($batchempty, $CriticalQueueSize, $headerfileumask);
+    my($getipfromheader);
 
     # Old code left over from single queue dir
     #$queuedirname = $global::MS->{inq}{dir};
@@ -859,6 +876,7 @@ my($sed) = "/bin/sed";
     # If there are too many messages in the queue, start processing in
     # directory storage order instead of date order.
     $CriticalQueueSize = MailScanner::Config::Value('criticalqueuesize');
+    $getipfromheader = MailScanner::Config::Value('getipfromheader');
 
     # Set what we will need the umask to be
     $headerfileumask = $global::MS->{work}->{fileumask};
@@ -1008,7 +1026,8 @@ my($sed) = "/bin/sed";
         #print STDERR "Adding $id to batch from $queuedirname\n";
 
         # Lock and read the qf file. Skip this message if the lock fails.
-        $newmessage = MailScanner::Message->new($id, $queuedirname);
+        $newmessage = MailScanner::Message->new($id, $queuedirname,
+                                                $getipfromheader);
         if ($newmessage eq 'INVALID') {
           $invalidfiles .= "$id ";
           next;
@@ -1156,3 +1175,4 @@ sub CheckQueueIsFlat {
 }
 
 1;
+
